# MedGPT: Medical Concept Forecasting from Clinical Narratives

<img src="https://github.com/w-is-h/MedGPT/blob/master/media/Patient%20timeline.png"/>

## Installation
`pip install --upgrade medgpt`

## !!! WORK IN PROGRESS !!!
